@@ -3,19 +3,21 @@ DIAMOND protein aligner
 Copyright (C) 2013-2017 Benjamin Buchfink <buchfink@gmail.com>
 
 This program is free software: you can redistribute it and/or modify
-it under the terms of the GNU Affero General Public License as
-published by the Free Software Foundation, either version 3 of the
-License, or (at your option) any later version.
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU Affero General Public License for more details.
+GNU General Public License for more details.
 
-You should have received a copy of the GNU Affero General Public License
+You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ****/
 
+#include <memory>
+#include <algorithm>
 #include "query_mapper.h"
 #include "../data/reference.h"
 #include "extend_ungapped.h"
@@ -24,6 +26,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "../output/daa_write.h"
 #include "../output/target_culling.h"
 
+using namespace std;
+
 bool Target::envelopes(const Hsp_traits &t, double p) const
 {
 	for (list<Hsp_traits>::const_iterator i = ts.begin(); i != ts.end(); ++i)
@@ -48,19 +52,40 @@ bool Target::is_enveloped(PtrVector<Target>::const_iterator begin, PtrVector<Tar
 	return false;
 }
 
+void Target::add_ranges(vector<unsigned> &v) {
+	for (const Hsp &hsp : hsps) {
+		const int i0 = hsp.query_source_range.begin_ / INTERVAL,
+			i1 = min(hsp.query_source_range.end_ / INTERVAL, int(v.size() - 1));
+		for (int i = i0; i <= i1; ++i)
+			v[i] = max(v[i], hsp.score);
+	}
+}
+
+bool Target::is_outranked(const vector<unsigned> &v, double treshold) {
+	for (const Hsp &hsp : hsps) {
+		const int i0 = hsp.query_source_range.begin_ / INTERVAL,
+			i1 = min(hsp.query_source_range.end_ / INTERVAL, int(v.size() - 1));
+		for (int i = i0; i <= i1; ++i)
+			if (hsp.score >= unsigned(v[i] * treshold))
+				return false;
+	}
+	return true;
+}
+
 int QueryMapper::raw_score_cutoff() const
 {
 	return score_matrix.rawscore(config.min_bit_score == 0 ? score_matrix.bitscore(config.max_evalue, (unsigned)query_seq(0).length()) : config.min_bit_score);
 }
 
-QueryMapper::QueryMapper(const Parameters &params, size_t query_id, Trace_pt_list::iterator begin, Trace_pt_list::iterator end) :
+QueryMapper::QueryMapper(const Parameters &params, size_t query_id, Trace_pt_list::iterator begin, Trace_pt_list::iterator end, bool target_parallel) :
 	parameters(params),
 	source_hits(std::make_pair(begin, end)),
 	query_id((unsigned)query_id),
 	targets_finished(0),
 	next_target(0),
 	source_query_len(get_source_query_len((unsigned)query_id)),
-	translated_query(get_translated_query(query_id))
+	translated_query(get_translated_query(query_id)),
+	target_parallel(target_parallel)
 {
 	seed_hits.reserve(source_hits.second - source_hits.first);
 }
@@ -71,10 +96,10 @@ void QueryMapper::init()
 		cout << "Query = " << query_ids::get()[query_id].c_str() << endl;
 	if (config.comp_based_stats == 1)
 		for (unsigned i = 0; i < align_mode.query_contexts; ++i)
-			query_cb.push_back(Bias_correction(query_seq(i)));
+			query_cb.emplace_back(query_seq(i));
 	if (config.ext == Config::greedy || config.ext == Config::more_greedy)
 		for (unsigned i = 0; i < align_mode.query_contexts; ++i)
-			profile.push_back(Long_score_profile(query_seq(i)));
+			profile.emplace_back(query_seq(i));
 			//profile.push_back(Long_score_profile());
 	targets.resize(count_targets());
 	if (targets.empty())
@@ -94,17 +119,22 @@ unsigned QueryMapper::count_targets()
 		const unsigned frame = hits[i].query_ % align_mode.query_contexts;
 		/*const Diagonal_segment d = config.comp_based_stats ? xdrop_ungapped(query_seq(frame), query_cb[frame], ref_seqs::get()[l.first], hits[i].seed_offset_, (int)l.second)
 			: xdrop_ungapped(query_seq(frame), ref_seqs::get()[l.first], hits[i].seed_offset_, (int)l.second);*/
-		const Diagonal_segment d = xdrop_ungapped(query_seq(frame), ref_seqs::get()[l.first], hits[i].seed_offset_, (int)l.second);
-		if (d.score >= config.min_ungapped_raw_score) {
+		if (target_parallel) {
+			seed_hits.emplace_back(frame, (unsigned)l.first, (unsigned)l.second, (unsigned)hits[i].seed_offset_, Diagonal_segment());
 			if (l.first != subject_id) {
 				subject_id = l.first;
 				++n_subject;
 			}
-			seed_hits.push_back(Seed_hit(frame,
-				(unsigned)l.first,
-				(unsigned)l.second,
-				hits[i].seed_offset_,
-				d));
+		}
+		else {
+			const Diagonal_segment d = xdrop_ungapped(query_seq(frame), ref_seqs::get()[l.first], hits[i].seed_offset_, (int)l.second);
+			if (d.score >= config.min_ungapped_raw_score) {
+				if (l.first != subject_id) {
+					subject_id = l.first;
+					++n_subject;
+				}
+				seed_hits.emplace_back(frame, (unsigned)l.first, (unsigned)l.second, (unsigned)hits[i].seed_offset_, d);
+			}
 		}
 	}
 	return n_subject;
@@ -155,7 +185,7 @@ void QueryMapper::rank_targets(double ratio, double factor)
 void QueryMapper::score_only_culling()
 {
 	std::stable_sort(targets.begin(), targets.end(), Target::compare);
-	auto_ptr<TargetCulling> target_culling(TargetCulling::get());
+	unique_ptr<TargetCulling> target_culling(TargetCulling::get());
 	const unsigned query_len = (unsigned)query_seq(0).length();
 	PtrVector<Target>::iterator i;
 	for (i = targets.begin(); i<targets.end();) {
@@ -184,13 +214,14 @@ bool QueryMapper::generate_output(TextBuffer &buffer, Statistics &stat, const Me
 	std::stable_sort(targets.begin(), targets.end(), Target::compare);
 
 	unsigned n_hsp = 0, n_target_seq = 0, hit_hsps = 0;
-	auto_ptr<TargetCulling> target_culling(TargetCulling::get());
+	unique_ptr<TargetCulling> target_culling(TargetCulling::get());
 	const unsigned query_len = (unsigned)query_seq(0).length();
 	size_t seek_pos = 0;
 	const char *query_title = query_ids::get()[query_id].c_str();
-	auto_ptr<Output_format> f(output_format->clone());
+	unique_ptr<Output_format> f(output_format->clone());
 
 	for (size_t i = 0; i < targets.size(); ++i) {
+
 		if ((config.min_bit_score == 0 && score_matrix.evalue(targets[i].filter_score, query_len) > config.max_evalue)
 			|| score_matrix.bitscore(targets[i].filter_score) < config.min_bit_score)
 			break;
@@ -230,7 +261,7 @@ bool QueryMapper::generate_output(TextBuffer &buffer, Statistics &stat, const Me
 						f->print_query_intro(query_id, query_title, source_query_len, buffer, false);
 				}
 				if (*f == Output_format::daa)
-					write_daa_record(buffer, *j, query_id, subject_id);
+					write_daa_record(buffer, *j, subject_id);
 				else
 					f->print_match(Hsp_context(*j,
 						query_id,
@@ -301,7 +332,8 @@ void Target::apply_filters(int dna_len, int subject_len, const char *query_title
 				&& i->identities == i->length
 				&& i->query_source_range.length() == (int)dna_len
 				&& i->subject_range.length() == (int)subject_len
-				&& strcmp(query_title, ref_title) == 0))
+				&& strcmp(query_title, ref_title) == 0)
+			|| (config.filter_locus && !i->subject_range.includes(config.filter_locus)))
 			i = hsps.erase(i);
 		else
 			++i;
