@@ -70,7 +70,8 @@ Config::Config(int argc, const char **argv)
 		.add_command("seed-stat", "")
 		.add_command("smith-waterman", "")
 		.add_command("protein-snps", "")
-		.add_command("cluster", "");
+		.add_command("cluster", "")
+		.add_command("translate", "");
 
 	Options_group general("General options");
 	general.add()
@@ -94,8 +95,9 @@ Config::Config(int argc, const char **argv)
 \tsstart means Start of alignment in subject\n\
 \tsend means End of alignment in subject\n\
 \tqseq means Aligned part of query sequence\n\
+\tfull_qseq means Query sequence\n\
 \tsseq means Aligned part of subject sequence\n\
-\tfull_sseq means Full subject sequence\n\
+\tfull_sseq means Subject sequence\n\
 \tevalue means Expect value\n\
 \tbitscore means Bit score\n\
 \tscore means Raw score\n\
@@ -118,7 +120,8 @@ Config::Config(int argc, const char **argv)
 \n\tDefault: qseqid sseqid pident length mismatch gapopen qstart qend sstart send evalue bitscore", output_format)
 ("verbose", 'v', "verbose console output", verbose)
 ("log", 0, "enable debug log", debug_log)
-("quiet", 0, "disable console output", quiet);
+("quiet", 0, "disable console output", quiet)
+("header", 0, "Write header lines to blast tabular format.", output_header);
 
 	Options_group makedb("Makedb options");
 	makedb.add()
@@ -130,6 +133,8 @@ Config::Config(int argc, const char **argv)
 		("strand", 0, "query strands to search (both/minus/plus)", query_strands, string("both"))
 		("un", 0, "file for unaligned queries", unaligned)
 		("al", 0, "file or aligned queries", aligned_file)
+		("unfmt", 0, "format of unaligned query file (fasta/fastq)", unfmt, string("fasta"))
+		("alfmt", 0, "format of aligned query file (fasta/fastq)", alfmt, string("fasta"))
 		("unal", 0, "report unaligned queries (0=no, 1=yes)", report_unaligned, -1)
 		("max-target-seqs", 'k', "maximum number of target sequences to report alignments for", max_alignments, uint64_t(25))
 		("top", 0, "report alignments within this percentage range of top alignment score (overrides --max-target-seqs)", toppercent, 100.0)
@@ -342,7 +347,7 @@ Config::Config(int argc, const char **argv)
 		;
 	}
 
-	invocation = join(' ', vector<string>(&argv[0], &argv[argc]));
+	invocation = join(" ", vector<string>(&argv[0], &argv[argc]));
 	log_stream << invocation << endl;
 
 	if (!no_auto_append) {
@@ -423,6 +428,11 @@ Config::Config(int argc, const char **argv)
 	if (query_strands != "both" && query_strands != "minus" && query_strands != "plus")
 		throw std::runtime_error("Invalid value for parameter --strand");
 
+	if (unfmt == "fastq" || alfmt == "fastq")
+		store_query_quality = true;
+	if (!aligned_file.empty())
+		log_stream << "Aligned file format: " << alfmt << endl;
+
 	/*log_stream << "sizeof(hit)=" << sizeof(hit) << " sizeof(packed_uint40_t)=" << sizeof(packed_uint40_t)
 		<< " sizeof(sorted_list::entry)=" << sizeof(sorted_list::entry) << endl;*/
 
