@@ -3,16 +3,16 @@ DIAMOND protein aligner
 Copyright (C) 2013-2017 Benjamin Buchfink <buchfink@gmail.com>
 
 This program is free software: you can redistribute it and/or modify
-it under the terms of the GNU Affero General Public License as
-published by the Free Software Foundation, either version 3 of the
-License, or (at your option) any later version.
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU Affero General Public License for more details.
+GNU General Public License for more details.
 
-You should have received a copy of the GNU Affero General Public License
+You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ****/
 
@@ -138,7 +138,7 @@ struct Sequence_set : public String_set<sequence::DELIMITER, 1>
 	}
 
 	template <typename _f, typename _filter>
-	void enum_seeds(Ptr_vector<_f> &f, const vector<size_t> &p, size_t shape_begin, size_t shape_end, const _filter *filter) const
+	void enum_seeds(PtrVector<_f> &f, const vector<size_t> &p, size_t shape_begin, size_t shape_end, const _filter *filter) const
 	{
 		Thread_pool threads;
 		for (unsigned i = 0; i < f.size(); ++i)
@@ -160,7 +160,7 @@ private:
 			const sequence seq = (*this)[i];
 			Reduction::reduce_seq(seq, buf);
 			for (size_t shape_id = shape_range.first; shape_id < shape_range.second; ++shape_id) {
-				const shape& sh = shapes[shape_id];
+				const Shape& sh = shapes[shape_id];
 				if (seq.length() < sh.length_) continue;
 				Seed_iterator it(buf, sh);
 				size_t j = 0;
@@ -182,7 +182,7 @@ private:
 		for (unsigned i = begin; i < end; ++i) {
 			const sequence seq = (*this)[i];
 			for (size_t shape_id = shape_range.first; shape_id < shape_range.second; ++shape_id) {
-				const shape& sh = shapes[shape_id];
+				const Shape& sh = shapes[shape_id];
 				if (seq.length() < sh.length_) continue;
 				const uint64_t shape_mask = sh.long_mask();
 				Hashed_seed_iterator<_b> it(seq, sh);
