@@ -3,22 +3,23 @@ DIAMOND protein aligner
 Copyright (C) 2013-2017 Benjamin Buchfink <buchfink@gmail.com>
 
 This program is free software: you can redistribute it and/or modify
-it under the terms of the GNU Affero General Public License as
-published by the Free Software Foundation, either version 3 of the
-License, or (at your option) any later version.
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU Affero General Public License for more details.
+GNU General Public License for more details.
 
-You should have received a copy of the GNU Affero General Public License
+You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ****/
 
 #ifndef SORTED_LIST_H_
 #define SORTED_LIST_H_
 
+#include <memory>
 #include "../util/util.h"
 #include "seed_histogram.h"
 #include "../basic/packed_loc.h"
@@ -235,7 +236,7 @@ private:
 			it->flush();
 		}
 		SeedPartitionRange range;
-		auto_ptr<sorted_list::buffered_iterator> it;
+		std::unique_ptr<sorted_list::buffered_iterator> it;
 	};
 
 	Limits limits_;
