@@ -3,16 +3,16 @@ DIAMOND protein aligner
 Copyright (C) 2013-2017 Benjamin Buchfink <buchfink@gmail.com>
 
 This program is free software: you can redistribute it and/or modify
-it under the terms of the GNU Affero General Public License as
-published by the Free Software Foundation, either version 3 of the
-License, or (at your option) any later version.
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU Affero General Public License for more details.
+GNU General Public License for more details.
 
-You should have received a copy of the GNU Affero General Public License
+You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ****/
 
@@ -100,7 +100,7 @@ struct Taxonomy
 	unsigned get_parent(unsigned taxid) const
 	{
 		if (taxid >= parent_.size())
-			throw std::runtime_error(string("No taxonomy node found for taxon id ") + to_string(taxid));
+			throw std::runtime_error(std::string("No taxonomy node found for taxon id ") + std::to_string(taxid));
 		return parent_[taxid];
 	}
 
@@ -115,4 +115,4 @@ private:
 
 };
 
-extern Taxonomy taxonomy;
\ No newline at end of file
+extern Taxonomy taxonomy;
