@@ -3,16 +3,16 @@ DIAMOND protein aligner
 Copyright (C) 2013-2017 Benjamin Buchfink <buchfink@gmail.com>
 
 This program is free software: you can redistribute it and/or modify
-it under the terms of the GNU Affero General Public License as
-published by the Free Software Foundation, either version 3 of the
-License, or (at your option) any later version.
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU Affero General Public License for more details.
+GNU General Public License for more details.
 
-You should have received a copy of the GNU Affero General Public License
+You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ****/
 
@@ -100,14 +100,14 @@ Bias_correction::Bias_correction(const sequence &seq):
 	}
 }
 
-int Bias_correction::operator()(const Hsp_data &hsp) const
+int Bias_correction::operator()(const Hsp &hsp) const
 {
 	float s = 0;
-	for (Hsp_data::Iterator i = hsp.begin(); i.good(); ++i) {
+	for (Hsp::Iterator i = hsp.begin(); i.good(); ++i) {
 		switch (i.op()) {
 		case op_match:
 		case op_substitution:
-			s += (*this)[i.query_pos];
+			s += (*this)[i.query_pos.translated];
 		default:
 			;
 		}
