@@ -3,22 +3,22 @@ DIAMOND protein aligner
 Copyright (C) 2013-2017 Benjamin Buchfink <buchfink@gmail.com>
 
 This program is free software: you can redistribute it and/or modify
-it under the terms of the GNU Affero General Public License as
-published by the Free Software Foundation, either version 3 of the
-License, or (at your option) any later version.
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU Affero General Public License for more details.
+GNU General Public License for more details.
 
-You should have received a copy of the GNU Affero General Public License
+You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ****/
 
 #include "output_format.h"
 
-void Pairwise_format::print_match(const Hsp_context& r, TextBuffer &out)
+void Pairwise_format::print_match(const Hsp_context& r, const Metadata &metadata, TextBuffer &out)
 {
 	static const unsigned width = 60;
 	const int dna_len = (int)r.query.source().length();
@@ -64,12 +64,12 @@ void Pairwise_format::print_match(const Hsp_context& r, TextBuffer &out)
 	}
 }
 
-void Pairwise_format::print_footer(Output_stream &out) const
+void Pairwise_format::print_footer(Consumer &out) const
 {
 
 }
 
-void Pairwise_format::print_query_epilog(TextBuffer &out, const char *query_title, bool unaligned) const
+void Pairwise_format::print_query_epilog(TextBuffer &out, const char *query_title, bool unaligned, const Parameters &params) const
 {
 }
 
@@ -81,8 +81,8 @@ void Pairwise_format::print_query_intro(size_t query_num, const char *query_name
 	}
 }
 
-void Pairwise_format::print_header(Output_stream &f, int mode, const char *matrix, int gap_open, int gap_extend, double evalue, const char *first_query_name, unsigned first_query_len) const
+void Pairwise_format::print_header(Consumer &f, int mode, const char *matrix, int gap_open, int gap_extend, double evalue, const char *first_query_name, unsigned first_query_len) const
 {
 	static const char* header = "BLASTP 2.3.0+\n\n\n";
-	f.write(header, strlen(header));
+	f.consume(header, strlen(header));
 }
\ No newline at end of file
