@@ -16,12 +16,16 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ****/
 
+#include <sstream>
 #include <set>
+#include <numeric>
 #include "../basic/match.h"
 #include "output_format.h"
 #include "../data/taxonomy.h"
 #include "../data/queries.h"
 
+using namespace std;
+
 const char* Blast_tab_format::field_str[] = {
 	"qseqid",		// 0 means Query Seq - id
 	"qgi",			// 1 means Query GI
@@ -75,7 +79,67 @@ const char* Blast_tab_format::field_str[] = {
 	"qqual",		// 49
 	"qnum",			// 50
 	"snum",			// 51
-	"scovhsp"		// 52
+	"scovhsp",		// 52
+	"full_qqual",	// 53
+	"full_qseq"		// 54
+};
+
+const char* Blast_tab_format::field_desc[] = {
+	"Query ID",		// 0 means Query Seq - id
+	"qgi",			// 1 means Query GI
+	"qacc",			// 2 means Query accesion
+	"qaccver",		// 3 means Query accesion.version
+	"Query length",	// 4 means Query sequence length
+	"Subject ID",		// 5 means Subject Seq - id
+	"Subject IDs",	// 6 means All subject Seq - id(s), separated by a ';'
+	"sgi",			// 7 means Subject GI
+	"sallgi",		// 8 means All subject GIs
+	"sacc",			// 9 means Subject accession
+	"saccver",		// 10 means Subject accession.version
+	"sallacc",		// 11 means All subject accessions
+	"Subject length",			// 12 means Subject sequence length
+	"Start of alignment in query",		// 13 means Start of alignment in query
+	"End of alignment in query",			// 14 means End of alignment in query
+	"Start of alignment in subject",		// 15 means Start of alignment in subject
+	"End of alignment in subject",			// 16 means End of alignment in subject
+	"Aligned part of query sequence",			// 17 means Aligned part of query sequence
+	"Aligned part of subject sequence",			// 18 means Aligned part of subject sequence
+	"Expected value",		// 19 means Expect value
+	"Bit score",		// 20 means Bit score
+	"Raw score",		// 21 means Raw score
+	"Alignment length",		// 22 means Alignment length
+	"Percentage of identical matches",		// 23 means Percentage of identical matches
+	"Number of identical matches",		// 24 means Number of identical matches
+	"Number of mismatches",		// 25 means Number of mismatches
+	"Number of positive-scoring matches",		// 26 means Number of positive - scoring matches
+	"Number of gap openings",		// 27 means Number of gap openings
+	"Total number of gaps",			// 28 means Total number of gaps
+	"Percentage of positive-scoring matches",			// 29 means Percentage of positive - scoring matches
+	"frames",		// 30 means Query and subject frames separated by a '/'
+	"Query frame",		// 31 means Query frame
+	"sframe",		// 32 means Subject frame
+	"Blast traceback operations",			// 33 means Blast traceback operations(BTOP)
+	"Subject Taxonomy IDs",		// 34 means unique Subject Taxonomy ID(s), separated by a ';'	(in numerical order)
+	"sscinames",	// 35 means unique Subject Scientific Name(s), separated by a ';'
+	"scomnames",	// 36 means unique Subject Common Name(s), separated by a ';'
+	"sblastnames",	// 37 means unique Subject Blast Name(s), separated by a ';'	(in alphabetical order)
+	"sskingdoms",	// 38 means unique Subject Super Kingdom(s), separated by a ';'	(in alphabetical order)
+	"Subject title",		// 39 means Subject Title
+	"Subject titles",	// 40 means All Subject Title(s), separated by a '<>'
+	"sstrand",		// 41 means Subject Strand
+	"qcovs",		// 42 means Query Coverage Per Subject
+	"Query coverage per HSP",		// 43 means Query Coverage Per HSP
+	"qcovus",		// 44 means Query Coverage Per Unique Subject(blastn only)
+	"Query title",		// 45 means Query title
+	"swdiff",		// 46
+	"time", 		// 47
+	"Subject sequence",	// 48
+	"Aligned part of query quality values",		// 49
+	"qnum",			// 50
+	"snum",			// 51
+	"scovhsp",		// 52
+	"Query quality values",	// 53
+	"Query sequence"		// 54
 };
 
 Blast_tab_format::Blast_tab_format() :
@@ -98,7 +162,7 @@ Blast_tab_format::Blast_tab_format() :
 			config.salltitles = true;
 		if (j == 48)
 			config.use_lazy_dict = true;
-		if (j == 49)
+		if (j == 49 || j == 53)
 			config.store_query_quality = true;
 	}
 }
@@ -250,7 +314,7 @@ void Blast_tab_format::print_match(const Hsp_context& r, const Metadata &metadat
 			out << r.subject_seq;
 			break;
 		case 49:
-			out << (*query_qual)[r.query_id].c_str();
+			out << (query_qual && (*query_qual)[r.query_id].present() ? (*query_qual)[r.query_id].subseq(r.query_source_range().begin_, r.query_source_range().end_).c_str() : "*");
 			break;
 		case 50:
 			out << query_block_to_database_id[r.query_id];
@@ -261,6 +325,12 @@ void Blast_tab_format::print_match(const Hsp_context& r, const Metadata &metadat
 		case 52:
 			out << (double)r.subject_range().length() * 100.0 / r.subject_len;
 			break;
+		case 53:
+			out << (query_qual && (*query_qual)[r.query_id].present() ? (*query_qual)[r.query_id].c_str() : "*");
+			break;
+		case 54:
+			r.query.source().print(out, input_value_traits);
+			break;
 		default:
 			throw std::runtime_error(string("Invalid output field: ") + field_str[*i]);
 		}
@@ -289,6 +359,7 @@ void Blast_tab_format::print_query_intro(size_t query_num, const char *query_nam
 			case 39:
 			case 40:
 			case 48:
+			case 49:
 				out << '*';
 				break;
 			case 12:
@@ -317,8 +388,11 @@ void Blast_tab_format::print_query_intro(size_t query_num, const char *query_nam
 			case 45:
 				out << query_name;
 				break;
-			case 49:
-				out << (*query_qual)[query_num].c_str();
+			case 53:
+				out << (query_qual && (*query_qual)[query_num].present() ? (*query_qual)[query_num].c_str() : "*");
+				break;
+			case 54:
+				(align_mode.query_translated ? query_source_seqs::get()[query_num] : query_seqs::get()[query_num]).print(out, input_value_traits);
 				break;
 			default:
 				throw std::runtime_error(string("Invalid output field: ") + field_str[*i]);
@@ -328,4 +402,15 @@ void Blast_tab_format::print_query_intro(size_t query_num, const char *query_nam
 		}
 		out << '\n';
 	}
+}
+
+void Blast_tab_format::print_header(Consumer &f, int mode, const char *matrix, int gap_open, int gap_extend, double evalue, const char *first_query_name, unsigned first_query_len) const {
+	if (!config.output_header)
+		return;
+	stringstream ss;
+	ss << "# DIAMOND v" << Const::version_string << ". http://github.com/bbuchfink/diamond" << endl;
+	ss << "# Invocation: " << config.invocation << endl;
+	ss << "# Fields: " << join(", ", apply(fields, [](unsigned i) -> string { return string(field_desc[i]); })) << endl;
+	const string s(ss.str());
+	f.consume(s.data(), s.length());
 }
\ No newline at end of file
