@@ -3,19 +3,20 @@ DIAMOND protein aligner
 Copyright (C) 2013-2017 Benjamin Buchfink <buchfink@gmail.com>
 
 This program is free software: you can redistribute it and/or modify
-it under the terms of the GNU Affero General Public License as
-published by the Free Software Foundation, either version 3 of the
-License, or (at your option) any later version.
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU Affero General Public License for more details.
+GNU General Public License for more details.
 
-You should have received a copy of the GNU Affero General Public License
+You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ****/
 
+#include <memory>
 #include "output.h"
 #include "../util/io/temp_file.h"
 #include "../data/queries.h"
@@ -26,6 +27,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "../data/ref_dictionary.h"
 #include "../util/log_stream.h"
 
+using namespace std;
+
 struct JoinFetcher
 {
 	static void init(const PtrVector<TempFile> &tmp_file)
@@ -66,11 +69,11 @@ struct JoinFetcher
 		unaligned_from = query_last + 1;
 		query_last = query_id;
 		for (unsigned i = 0; i < buf.size(); ++i)
-			if (query_ids[i] == query_id && query_id != IntermediateRecord::finished)
+			if (query_ids[i] == query_id && query_id != IntermediateRecord::FINISHED)
 				fetch(i);
 			else
 				buf[i].clear();
-		return next() != IntermediateRecord::finished;
+		return next() != IntermediateRecord::FINISHED;
 	}
 	static PtrVector<InputFile> files;
 	static vector<unsigned> query_ids;
@@ -85,15 +88,15 @@ unsigned JoinFetcher::query_last;
 
 struct JoinWriter
 {
-	JoinWriter(OutputFile &f):
+	JoinWriter(Consumer &f):
 		f_(f)
 	{}
 	void operator()(TextBuffer& buf)
 	{
-		f_.write(buf.get_begin(), buf.size());
+		f_.consume(buf.get_begin(), buf.size());
 		buf.clear();
 	}
-	OutputFile &f_;
+	Consumer &f_;
 };
 
 struct Join_record
@@ -172,7 +175,7 @@ void join_query(vector<BinaryBuffer> &buf, TextBuffer &out, Statistics &statisti
 	TranslatedSequence query_seq(get_translated_query(query));
 	BlockJoiner joiner(buf);
 	vector<IntermediateRecord> target_hsp;
-	auto_ptr<TargetCulling> culling(TargetCulling::get());
+	unique_ptr<TargetCulling> culling(TargetCulling::get());
 
 	unsigned n_target_seq = 0;
 		
@@ -219,7 +222,7 @@ void join_worker(Task_queue<TextBuffer, JoinWriter> *queue, const Parameters *pa
 	Statistics stat;
 	const String_set<0>& qids = query_ids::get();
 
-	while (queue->get(n, out, fetcher) && fetcher.query_id != IntermediateRecord::finished) {
+	while (queue->get(n, out, fetcher) && fetcher.query_id != IntermediateRecord::FINISHED) {
 		stat.inc(Statistics::ALIGNED);
 		size_t seek_pos;
 
@@ -233,7 +236,7 @@ void join_worker(Task_queue<TextBuffer, JoinWriter> *queue, const Parameters *pa
 			}
 		}
 
-		auto_ptr<Output_format> f(output_format->clone());
+		unique_ptr<Output_format> f(output_format->clone());
 
 		if (*f == Output_format::daa)
 			seek_pos = write_daa_query_record(*out, query_name, query_seq);
@@ -253,7 +256,7 @@ void join_worker(Task_queue<TextBuffer, JoinWriter> *queue, const Parameters *pa
 	statistics += stat;
 }
 
-void join_blocks(unsigned ref_blocks, OutputFile &master_out, const PtrVector<TempFile> &tmp_file, const Parameters &params, const Metadata &metadata, DatabaseFile &db_file)
+void join_blocks(unsigned ref_blocks, Consumer &master_out, const PtrVector<TempFile> &tmp_file, const Parameters &params, const Metadata &metadata, DatabaseFile &db_file)
 {
 	//ReferenceDictionary::get().init_rev_map();
 	task_timer timer("Building reference dictionary", 3);
