@@ -3,22 +3,23 @@ DIAMOND protein aligner
 Copyright (C) 2013-2017 Benjamin Buchfink <buchfink@gmail.com>
 
 This program is free software: you can redistribute it and/or modify
-it under the terms of the GNU Affero General Public License as
-published by the Free Software Foundation, either version 3 of the
-License, or (at your option) any later version.
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU Affero General Public License for more details.
+GNU General Public License for more details.
 
-You should have received a copy of the GNU Affero General Public License
+You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ****/
 
 #ifndef OUTPUT_H_
 #define OUTPUT_H_
 
+#include <memory>
 #include <map>
 #include "../util/io/output_file.h"
 #include "../basic/packed_transcript.h"
@@ -28,6 +29,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "../data/ref_dictionary.h"
 #include "../basic/parameters.h"
 #include "../data/metadata.h"
+#include "../util/io/consumer.h"
 
 inline unsigned get_length_flag(unsigned x)
 {
@@ -101,22 +103,22 @@ struct IntermediateRecord
 			.write_packed(match.subject_range.begin_)
 			<< match.transcript.data();
 	}
-	static void finish_file(OutputFile &f)
+	static void finish_file(Consumer &f)
 	{
-		unsigned x = finished;
-		f.write(&x, 1);
+		const uint32_t i = FINISHED;
+		f.consume(reinterpret_cast<const char*>(&i), 4);
 	}
-	enum { finished = 0xffffffffu };
+	static const uint32_t FINISHED = 0xffffffffu;
 	uint32_t query_id, subject_id, score, query_begin, subject_begin, query_end;
 	uint8_t flag;
 	Packed_transcript transcript;
 };
 
-void join_blocks(unsigned ref_blocks, OutputFile &master_out, const PtrVector<TempFile> &tmp_file, const Parameters &params, const Metadata &metadata, DatabaseFile &db_file);
+void join_blocks(unsigned ref_blocks, Consumer &master_out, const PtrVector<TempFile> &tmp_file, const Parameters &params, const Metadata &metadata, DatabaseFile &db_file);
 
 struct OutputSink
 {
-	OutputSink(size_t begin, OutputFile *f) :
+	OutputSink(size_t begin, Consumer *f) :
 		f_(f),
 		next_(begin),
 		size_(0),
@@ -139,11 +141,11 @@ struct OutputSink
 	{
 		return next_;
 	}
-	static auto_ptr<OutputSink> instance;
+	static std::unique_ptr<OutputSink> instance;
 private:
 	void flush(TextBuffer *buf);
 	tthread::mutex mtx_;
-	OutputFile* const f_;
+	Consumer* const f_;
 	std::map<size_t, TextBuffer*> backlog_;
 	size_t next_, size_, max_size_;
 };
