@@ -1,18 +1,18 @@
 /****
 DIAMOND protein aligner
-Copyright (C) 2013-2017 Benjamin Buchfink <buchfink@gmail.com>
+Copyright (C) 2013-2018 Benjamin Buchfink <buchfink@gmail.com>
 
 This program is free software: you can redistribute it and/or modify
-it under the terms of the GNU Affero General Public License as
-published by the Free Software Foundation, either version 3 of the
-License, or (at your option) any later version.
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU Affero General Public License for more details.
+GNU General Public License for more details.
 
-You should have received a copy of the GNU Affero General Public License
+You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ****/
 
@@ -22,9 +22,9 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "../data/reference.h"
 #include "../util/escape_sequences.h"
 
-using std::endl;
+using namespace std;
 
-auto_ptr<Output_format> output_format;
+unique_ptr<Output_format> output_format;
 
 void print_escaped_until(TextBuffer &buf, const char *s, const char *delimiters, const EscapeSequences *esc)
 {
@@ -79,7 +79,7 @@ void Output_format::print_title(TextBuffer &buf, const char *id, bool full_title
 void print_hsp(Hsp &hsp, const TranslatedSequence &query)
 {
 	TextBuffer buf;
-	Pairwise_format().print_match(Hsp_context(hsp, 0, query, "", 0, 0, "", 0, 0, 0), buf);
+	Pairwise_format().print_match(Hsp_context(hsp, 0, query, "", 0, 0, "", 0, 0, 0, sequence()), Metadata(), buf);
 	buf << '\0';
 	cout << buf.get_begin() << endl;
 }
@@ -99,7 +99,7 @@ Output_format* get_output_format()
 		return new Sam_format;
 	else if (f[0] == "xml" || f[0] == "5")
 		return new XML_format;
-	else if ((config.command == Config::blastp || config.command == Config::blastx) && (f[0] == "daa" || f[0] == "100"))
+	else if (f[0] == "daa" || f[0] == "100")
 		return new DAA_format;
 	else if (f[0] == "0")
 		return new Pairwise_format;
@@ -107,13 +107,19 @@ Output_format* get_output_format()
 		return new Null_format;
 	else if (f[0] == "102")
 		return new Taxon_format;
+	else if (f[0] == "paf" || f[0] == "103")
+		return new PAF_format;
 	else
 		throw std::runtime_error("Invalid output format. Allowed values: 0,5,6,100,101,102");
 }
 
-void init_output()
+void init_output(bool have_taxon_id_lists, bool have_taxon_nodes)
 {
-	output_format = auto_ptr<Output_format>(get_output_format());
+	output_format = unique_ptr<Output_format>(get_output_format());
+	if (output_format->needs_taxon_id_lists && !have_taxon_id_lists)
+		throw std::runtime_error("Output format requires taxonomy mapping information built into the database (use --taxonmap parameter for the makedb command). Taxonomy features are not supported for the DAA format.");
+	if (output_format->needs_taxon_nodes && !have_taxon_nodes)
+		throw std::runtime_error("Output format requires taxonomy nodes information built into the database (use --taxonnodes parameter for the makedb command). Taxonomy features are not supported for the DAA format.");
 	if (*output_format == Output_format::taxon && config.toppercent == 100.0)
 		config.toppercent = 10.0;
 	if (config.toppercent == 100.0) {
@@ -129,7 +135,7 @@ void init_output()
 		message_stream << "Percentage range of top alignment score to report hits: " << config.toppercent << endl;
 }
 
-void XML_format::print_match(const Hsp_context &r, TextBuffer &out)
+void XML_format::print_match(const Hsp_context &r, const Metadata &metadata, TextBuffer &out)
 {
 	if(r.hsp_num == 0) {
 		if (r.hit_num > 0)
@@ -198,7 +204,7 @@ void XML_format::print_match(const Hsp_context &r, TextBuffer &out)
 		<< "    </Hsp>" << '\n';
 }
 
-void XML_format::print_header(Output_stream &f, int mode, const char *matrix, int gap_open, int gap_extend, double evalue, const char *first_query_name, unsigned first_query_len) const
+void XML_format::print_header(Consumer &f, int mode, const char *matrix, int gap_open, int gap_extend, double evalue, const char *first_query_name, unsigned first_query_len) const
 {
 	std::stringstream ss;
 	ss << "<?xml version=\"1.0\"?>" << endl
@@ -225,7 +231,7 @@ void XML_format::print_header(Output_stream &f, int mode, const char *matrix, in
 		<< "    </Parameters>" << endl
 		<< "  </BlastOutput_param>" << endl
 		<< "<BlastOutput_iterations>" << endl;
-	f.write(ss.str().c_str(), ss.str().length());
+	f.consume(ss.str().c_str(), ss.str().length());
 }
 
 void XML_format::print_query_intro(size_t query_num, const char *query_name, unsigned query_len, TextBuffer &out, bool unaligned) const
@@ -240,7 +246,7 @@ void XML_format::print_query_intro(size_t query_num, const char *query_name, uns
 		<< "<Iteration_hits>" << '\n';
 }
 
-void XML_format::print_query_epilog(TextBuffer &out, const char *query_title, bool unaligned) const
+void XML_format::print_query_epilog(TextBuffer &out, const char *query_title, bool unaligned, const Parameters &parameters) const
 {
 	if (!unaligned) {
 		out << "  </Hit_hsps>" << '\n'
@@ -249,8 +255,8 @@ void XML_format::print_query_epilog(TextBuffer &out, const char *query_title, bo
 	((out << "</Iteration_hits>" << '\n'
 		<< "  <Iteration_stat>" << '\n'
 		<< "    <Statistics>" << '\n'
-		<< "      <Statistics_db-num>" << (size_t)ref_header.sequences << "</Statistics_db-num>" << '\n'
-		<< "      <Statistics_db-len>" << (size_t)config.db_size << "</Statistics_db-len>" << '\n'
+		<< "      <Statistics_db-num>" << parameters.db_seqs << "</Statistics_db-num>" << '\n'
+		<< "      <Statistics_db-len>" << parameters.db_letters << "</Statistics_db-len>" << '\n'
 		<< "      <Statistics_hsp-len>0</Statistics_hsp-len>" << '\n'
 		<< "      <Statistics_eff-space>0</Statistics_eff-space>" << '\n'
 		<< "      <Statistics_kappa>").print_d(score_matrix.k()) << "</Statistics_kappa>" << '\n'
@@ -261,10 +267,10 @@ void XML_format::print_query_epilog(TextBuffer &out, const char *query_title, bo
 		<< "</Iteration>" << '\n';
 }
 
-void XML_format::print_footer(Output_stream &f) const
+void XML_format::print_footer(Consumer &f) const
 {
 	std::stringstream ss;
 	ss << "</BlastOutput_iterations>" << endl
 		<< "</BlastOutput>";
-	f.write(ss.str().c_str(), ss.str().length());
+	f.consume(ss.str().c_str(), ss.str().length());
 }
\ No newline at end of file
