@@ -3,21 +3,22 @@ DIAMOND protein aligner
 Copyright (C) 2013-2018 Benjamin Buchfink <buchfink@gmail.com>
 
 This program is free software: you can redistribute it and/or modify
-it under the terms of the GNU Affero General Public License as
-published by the Free Software Foundation, either version 3 of the
-License, or (at your option) any later version.
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU Affero General Public License for more details.
+GNU General Public License for more details.
 
-You should have received a copy of the GNU Affero General Public License
+You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ****/
 
 #include <iostream>
 #include <limits>
+#include <memory>
 #include "../data/reference.h"
 #include "../data/queries.h"
 #include "../basic/statistics.h"
@@ -33,9 +34,12 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "../data/ref_dictionary.h"
 #include "../data/metadata.h"
 #include "../search/search.h"
+#include "workflow.h"
+#include "../util/io/consumer.h"
 
-using std::endl;
-using std::cout;
+using namespace std;
+
+namespace Workflow { namespace Search {
 
 struct Search_context
 {
@@ -128,7 +132,7 @@ void run_ref_chunk(DatabaseFile &db_file,
 	unsigned query_chunk,
 	pair<size_t, size_t> query_len_bounds,
 	char *query_buffer,
-	OutputFile &master_out,
+	Consumer &master_out,
 	PtrVector<TempFile> &tmp_file,
 	const Parameters &params,
 	const Metadata &metadata,
@@ -162,7 +166,7 @@ void run_ref_chunk(DatabaseFile &db_file,
 	timer.go("Deallocating buffers");
 	delete[] ref_buffer;
 
-	OutputFile* out;
+	Consumer* out;
 	if (blocked_processing) {
 		timer.go("Opening temporary output file");
 		tmp_file.push_back(new TempFile());
@@ -187,9 +191,11 @@ void run_ref_chunk(DatabaseFile &db_file,
 void run_query_chunk(DatabaseFile &db_file,
 	Timer &total_timer,
 	unsigned query_chunk,
-	OutputFile &master_out,
+	Consumer &master_out,
 	OutputFile *unaligned_file,
-	const Metadata &metadata)
+	OutputFile *aligned_file,
+	const Metadata &metadata,
+	const Options &options)
 {
 	const Parameters params(db_file.ref_header.sequences, db_file.ref_header.letters);
 
@@ -238,7 +244,13 @@ void run_query_chunk(DatabaseFile &db_file,
 	vector<unsigned> block_to_database_id;
 	timer.finish();
 	
-	for (current_ref_block = 0; db_file.load_seqs(block_to_database_id, (size_t)(config.chunk_size*1e9), true, true, metadata.taxon_filter); ++current_ref_block)
+	for (current_ref_block = 0; db_file.load_seqs(block_to_database_id,
+		(size_t)(config.chunk_size*1e9),
+		true,
+		&ref_seqs::data_,
+		&ref_ids::data_,
+		true,
+		options.db_filter ? options.db_filter : metadata.taxon_filter); ++current_ref_block)
 		run_ref_chunk(db_file, total_timer, query_chunk, query_len_bounds, query_buffer, master_out, tmp_file, params, metadata, block_to_database_id);
 
 	timer.go("Deallocating buffers");
@@ -255,40 +267,68 @@ void run_query_chunk(DatabaseFile &db_file,
 		timer.go("Writing unaligned queries");
 		write_unaligned(unaligned_file);
 	}
+	if (aligned_file) {
+		timer.go("Writing aligned queries");
+		write_aligned(aligned_file);
+	}
 
 	timer.go("Deallocating queries");
 	delete query_seqs::data_;
 	delete query_ids::data_;
 	delete query_source_seqs::data_;
+	delete query_qual;
 	if (*output_format != Output_format::daa)
 		ReferenceDictionary::get().clear();
 }
 
-void master_thread(DatabaseFile &db_file, Timer &total_timer, Metadata &metadata)
+void master_thread(DatabaseFile *db_file, Timer &total_timer, Metadata &metadata, const Options &options)
 {
-	if(config.query_file.empty())
-		std::cerr << "Query file parameter (--query/-q) is missing. Input will be read from stdin." << endl;
 	task_timer timer("Opening the input file", true);
-	auto_ptr<TextInputFile> query_file(new TextInputFile(config.query_file));
-	const Sequence_file_format *format_n(guess_format(*query_file));
+	unique_ptr<TextInputFile> query_file;
+	const Sequence_file_format *format_n = nullptr;
+	if (!options.self) {
+		if (config.query_file.empty())
+			std::cerr << "Query file parameter (--query/-q) is missing. Input will be read from stdin." << endl;
+		query_file.reset(new TextInputFile(config.query_file));
+		format_n = guess_format(*query_file);
+	}
 
 	current_query_chunk = 0;
 
 	timer.go("Opening the output file");
-	auto_ptr<OutputFile> master_out(new OutputFile(config.output_file, config.compression == 1));
+	Consumer *master_out(options.consumer ? options.consumer : new OutputFile(config.output_file, config.compression == 1));
 	if (*output_format == Output_format::daa)
-		init_daa(*master_out);
-	auto_ptr<OutputFile> unaligned_file;
+		init_daa(*static_cast<OutputFile*>(master_out));
+	unique_ptr<OutputFile> unaligned_file, aligned_file;
 	if (!config.unaligned.empty())
-		unaligned_file = auto_ptr<OutputFile>(new OutputFile(config.unaligned));
+		unaligned_file = unique_ptr<OutputFile>(new OutputFile(config.unaligned));
+	if (!config.aligned_file.empty())
+		aligned_file = unique_ptr<OutputFile>(new OutputFile(config.aligned_file));
 	timer.finish();
 
+	size_t query_file_offset = 0;
+
 	for (;; ++current_query_chunk) {
 		task_timer timer("Loading query sequences", true);
-		size_t n_query_seqs;
-		n_query_seqs = load_seqs(*query_file, *format_n, &query_seqs::data_, query_ids::data_, &query_source_seqs::data_, (size_t)(config.chunk_size * 1e9), config.qfilt);
-		if (n_query_seqs == 0)
-			break;
+
+		if (options.self) {
+			db_file->seek_seq(query_file_offset);
+			if (!db_file->load_seqs(query_block_to_database_id,
+				(size_t)(config.chunk_size * 1e9),
+				true,
+				&query_seqs::data_,
+				&query_ids::data_,
+				true,
+				options.db_filter))
+				break;
+			query_file_offset = db_file->tell_seq();
+		}
+		else
+			if (!load_seqs(*query_file, *format_n, &query_seqs::data_, query_ids::data_, &query_source_seqs::data_,
+				config.store_query_quality ? &query_qual : nullptr,
+				(size_t)(config.chunk_size * 1e9), config.qfilt))
+				break;
+
 		timer.finish();
 		query_seqs::data_->print_stats();
 
@@ -296,29 +336,37 @@ void master_thread(DatabaseFile &db_file, Timer &total_timer, Metadata &metadata
 			output_format->print_header(*master_out, align_mode.mode, config.matrix.c_str(), score_matrix.gap_open(), score_matrix.gap_extend(), config.max_evalue, query_ids::get()[0].c_str(),
 				unsigned(align_mode.query_translated ? query_source_seqs::get()[0].length() : query_seqs::get()[0].length()));
 
-		if (config.masking == 1) {
+		if (config.masking == 1 && !options.self) {
 			timer.go("Masking queries");
 			mask_seqs(*query_seqs::data_, Masking::get());
 			timer.finish();
 		}
 
-		run_query_chunk(db_file, total_timer, current_query_chunk, *master_out, unaligned_file.get(), metadata);
+		run_query_chunk(*db_file, total_timer, current_query_chunk, *master_out, unaligned_file.get(), aligned_file.get(), metadata, options);
 	}
 
-	timer.go("Closing the input file");
-	query_file->close();
+	if (query_file) {
+		timer.go("Closing the input file");
+		query_file->close();
+	}
 
 	timer.go("Closing the output file");
 	if (*output_format == Output_format::daa)
-		finish_daa(*master_out, db_file);
+		finish_daa(*static_cast<OutputFile*>(master_out), *db_file);
 	else
 		output_format->print_footer(*master_out);
-	master_out->close();
+	master_out->finalize();
+	if (!options.consumer) delete master_out;
 	if (unaligned_file.get())
 		unaligned_file->close();
+	if (aligned_file.get())
+		aligned_file->close();
 	
-	timer.go("Closing the database file");
-	db_file.close();
+	if (!options.db) {
+		timer.go("Closing the database file");
+		db_file->close();
+		delete db_file;
+	}
 
 	timer.go("Deallocating taxonomy");
 	metadata.free();
@@ -328,7 +376,7 @@ void master_thread(DatabaseFile &db_file, Timer &total_timer, Metadata &metadata
 	statistics.print();
 }
 
-void master_thread_di()
+void run(const Options &options)
 {
 	Timer timer2;
 	timer2.start();
@@ -347,33 +395,33 @@ void master_thread_di()
 	}
 
 	task_timer timer("Opening the database", 1);
-	DatabaseFile db_file;
+	DatabaseFile *db_file = options.db ? options.db : DatabaseFile::auto_create_from_fasta();
 	timer.finish();
 
-	init_output(db_file.has_taxon_id_lists(), db_file.has_taxon_nodes());
+	init_output(db_file->has_taxon_id_lists(), db_file->has_taxon_nodes());
 
 	verbose_stream << "Reference = " << config.database << endl;
-	verbose_stream << "Sequences = " << db_file.ref_header.sequences << endl;
-	verbose_stream << "Letters = " << db_file.ref_header.letters << endl;
+	verbose_stream << "Sequences = " << db_file->ref_header.sequences << endl;
+	verbose_stream << "Letters = " << db_file->ref_header.letters << endl;
 	verbose_stream << "Block size = " << (size_t)(config.chunk_size * 1e9) << endl;
-	Config::set_option(config.db_size, (uint64_t)db_file.ref_header.letters);
-	score_matrix.set_db_letters(db_file.ref_header.letters);
+	Config::set_option(config.db_size, (uint64_t)db_file->ref_header.letters);
+	score_matrix.set_db_letters(db_file->ref_header.letters);
 
-	set_max_open_files(config.query_bins * config.threads_ + unsigned(db_file.ref_header.letters / (size_t)(config.chunk_size * 1e9)) + 16);
+	set_max_open_files(config.query_bins * config.threads_ + unsigned(db_file->ref_header.letters / (size_t)(config.chunk_size * 1e9)) + 16);
 
 	Metadata metadata;
 	if (output_format->needs_taxon_id_lists || !config.taxonlist.empty()) {
-		if (!config.taxonlist.empty() && db_file.header2.taxon_array_offset == 0)
+		if (!config.taxonlist.empty() && db_file->header2.taxon_array_offset == 0)
 			throw std::runtime_error("--taxonlist option requires taxonomy mapping built into the database.");
 		timer.go("Loading taxonomy mapping");
-		metadata.taxon_list = new TaxonList(db_file.seek(db_file.header2.taxon_array_offset), db_file.ref_header.sequences, db_file.header2.taxon_array_size);
+		metadata.taxon_list = new TaxonList(db_file->seek(db_file->header2.taxon_array_offset), db_file->ref_header.sequences, db_file->header2.taxon_array_size);
 		timer.finish();
 	}
 	if (output_format->needs_taxon_nodes || !config.taxonlist.empty()) {
-		if (!config.taxonlist.empty() && db_file.header2.taxon_nodes_offset == 0)
+		if (!config.taxonlist.empty() && db_file->header2.taxon_nodes_offset == 0)
 			throw std::runtime_error("--taxonlist option requires taxonomy nodes built into the database.");
 		timer.go("Loading taxonomy nodes");
-		metadata.taxon_nodes = new TaxonomyNodes(db_file.seek(db_file.header2.taxon_nodes_offset));
+		metadata.taxon_nodes = new TaxonomyNodes(db_file->seek(db_file->header2.taxon_nodes_offset));
 		if (!config.taxonlist.empty()) {
 			timer.go("Building taxonomy filter");
 			metadata.taxon_filter = new TaxonomyFilter(config.taxonlist, *metadata.taxon_list, *metadata.taxon_nodes);
@@ -381,5 +429,7 @@ void master_thread_di()
 		timer.finish();
 	}
 
-	master_thread(db_file, timer2, metadata);
-}
\ No newline at end of file
+	master_thread(db_file, timer2, metadata, options);
+}
+
+}}
\ No newline at end of file
