@@ -42,11 +42,11 @@ void info();
 void seed_stat();
 void pairwise();
 void protein_snps();
+void translate();
 
 int main(int ac, const char* av[])
 {
 	try {
-
 		check_simd();
 		config = Config(ac, av);
 
@@ -126,6 +126,9 @@ int main(int ac, const char* av[])
 		case Config::cluster:
 			Workflow::Cluster::run();
 			break;
+		case Config::translate:
+			translate();
+			break;
 #ifdef EXTRA
 		case Config::test_extra:
 			test_main();
