@@ -3,20 +3,21 @@ DIAMOND protein aligner
 Copyright (C) 2013-2017 Benjamin Buchfink <buchfink@gmail.com>
 
 This program is free software: you can redistribute it and/or modify
-it under the terms of the GNU Affero General Public License as
-published by the Free Software Foundation, either version 3 of the
-License, or (at your option) any later version.
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU Affero General Public License for more details.
+GNU General Public License for more details.
 
-You should have received a copy of the GNU Affero General Public License
+You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ****/
 
 #include "simd.h"
+#include "log_stream.h"
 
 #ifdef _WIN32
 #define cpuid(info,x)    __cpuidex(info,x,0)
@@ -57,4 +58,17 @@ void check_simd()
 	if ((info[2] & (1 << 19)) == 0)
 		throw std::runtime_error("CPU does not support SSE4.1. Please compile the software from source.");
 #endif
+}
+
+void simd_messages()
+{
+#ifdef __SSSE3__
+	verbose_stream << "SSSE3 enabled." << endl;
+#endif
+#ifdef __SSE4_1__
+	verbose_stream << "SSE4.1 enabled." << endl;
+#endif
+#ifdef __POPCNT__
+	verbose_stream << "POPCNT enabled." << endl;
+#endif
 }
\ No newline at end of file
