@@ -3,16 +3,16 @@ DIAMOND protein aligner
 Copyright (C) 2013-2017 Benjamin Buchfink <buchfink@gmail.com>
 
 This program is free software: you can redistribute it and/or modify
-it under the terms of the GNU Affero General Public License as
-published by the Free Software Foundation, either version 3 of the
-License, or (at your option) any later version.
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU Affero General Public License for more details.
+GNU General Public License for more details.
 
-You should have received a copy of the GNU Affero General Public License
+You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ****/
 
@@ -24,7 +24,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <stdexcept>
 #include "fast_mutex.h"
 #include "tinythread.h"
-#include "util.h"
+#include "tls.h"
 
 using tthread::thread;
 using std::vector;
@@ -54,6 +54,13 @@ struct Atomic
 		mtx_.unlock();
 		return r;
 	}
+	_t post_add(const _t &v) {
+		mtx_.lock();
+		_t r = v_;
+		v_ += v;
+		mtx_.unlock();
+		return r;
+	}
 private:
 	volatile _t v_;
 	tthread::mutex mtx_;
